Examples_Home

# Examples¶

pyMez documentaion contains interactive examples in jupyter explaining the package itself, general themes in programming and data analysis and specific examples pertinent to laboratory work.

## pyMez Specific Examples

Examples specific to the pyMez package.

### Design Examples

- Module Structure for pyMez
  An example of naming and module design in pyMez.
- Development Environment
  A detailed description of the software installed on my computer during development of pyMez.
- pyMez Format Handling
  A detailed description of the formats that pyMez was designed to handle. It was written 10/2016 and may be slightly dated.

### InstrumentControl Examples

- Simple VNA Measurement Example
  An example of taking scattering parameters and wave parameters from a VNA.
- WR15 VNA Measurement Example
  An example of using the VNA class to measure one-port and two-port scattering and wave parameters and then save them. These measurements use the ZVA67 with a WR15 extension head at 50-75GHz.This is more of a lab example but shows the VNA class in action.
- Example of Fake Instrument
  An example of the FakeInstrument mode that occurs when the device is not connected. It serves as a diagnostic to show the commands that get sent by any class.

### Analysis Examples

- Fitting Example
  An example of how to use FunctionalModel and DataSimulator models to fit and synthesize data
- Interpolation Example
  An example of how to interpolate a data table keeping the metadata and header
- Program Analysis
  An example of how to create a function diagram using the ProgramAnalysis module
- Applying a Calibration
  An example of how to apply a two port calibration in s4p format to a two port file in s2p format.
- Calrep Example
  An example of how to create uncertainties using calibration report program.
- Check Standard Report Example
  An example of how to create HTML reports that summarize the checkstandard measurements for a particular device.
- MUF Reference Curve Example
  An example of how to create a reference curve using a MUF .meas file and support directory. Also has a brief example of the DataHandler MUFMeasurement.

### DataHandlers Examples

- Touchstone (.s2p) Example
  An example of how to use the classes in TouchstoneModels to deal with .snp files
- Converting s2p to Interactive Html
  An example of how to convert s2p to an interactive html file and html class.
- AsciiDataTable Example
  An example of how to use the classes in GeneralModels to deal with a table with a header/footer and with an arbitrary set of formatting.
- XML Log Example
  An example of how to use the classes in XMLModels to deal with logging activity
- ZipArchive Example
  An example of how to use the classes in ZipModels to create, save and add files to a zip file.
- Table Graph Example
  An example of how to use the classes in GraphModels to change data formats of a table.

## General Examples

Examples for general tasks in python and related packages.

- General Python and Jupyter Intro
  An introduction to using python and the jupyter notebook with examples in python/jupyter setup, basic data types, functions, classes, plotting, interactive design, and instrument control
- Example Plots
  An example of interactive plots in jupyter.
- An example of HTML, CSS and Javascript
  A description of creating html pages with formating and basic javascript.
- An example of a Linear Fit
  A description of creating a linear fit and interactive plotting with residuals.

## Lab Examples

Examples pertinent to work in my laboratory.

- Automating MUF Example
  An example of running the MUF as a script in python. The example covers running several applications such as VNAUncert, Measurement and PostProcessor using pythonnet. Additionally, there is an example using pyMez to create a series of MUF results for a set of different Monte Carlo trials.
- Comparison of using the StatistiCAL package and pyMez to apply corrections
  A comparison of correcting from 12 term corrections and 8-term corrections both reciprocal and non-reciprocal generated by statistiCAL and applied by both pyMez and StatistiCAL. The ultimate result is they agree (statistiCAL only applies the reciprocal ones).
- A work flow for PNA Grabber and Microwave Uncertainty Framework
  An introduction to using the NIST* software in two-port microwave calibrations.
- General Data Guidance for XML/Ascii Data
  General data guidance for storing data more effectively in 672.01
- Example of creating check standard and dut database
  A detailed description of how to create a de-normalized database using the ascii.dut and converted check standard data.
- Description of our current data processing scheme in Sparameters
  An outlined description of how we take data currently and places we need improvement. In addition, an outline of the imporvement needed at each step.
- Git Work Flow For Single Contributor
  An outline of my Git work flow for a single contributor.
- Refactoring a python program example
  A set of thoughts and steps to refactor code to make it more shareable.

`* This work and any depencies are not endorsed by the National Institute of Standards and Technology`